==> wikindx3_4_3.tar.gz: wikindx3/config.php <==
<?php
/**********************************************************************************
WIKINDX: Bibliographic Management system.
Copyright (C)

This program is free software; you can redistribute it and/or modify it under the terms 
of the GNU General Public License as published by the Free Software Foundation; either 
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; 
if not, write to the 
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

The WIKINDX Team 2006
sirfragalot@users.sourceforge.net
**********************************************************************************/
/*****
*
* WIKINDX v3.x CONFIGURATION FILE
*
* NB. BEFORE YOU MAKE CHANGES TO THIS FILE, BACK IT UP!
* NB. BEFORE YOU MAKE CHANGES TO THIS FILE, BACK IT UP!
* NB. BEFORE YOU MAKE CHANGES TO THIS FILE, BACK IT UP!
*
* If you make changes, backup the edited file as future upgrades of WIKINDX will write over this file - no questions asked!
*****/

/**********************************************************************************/

/*****
START DATABASE CONFIGURATION
*****/
// host on which the relational db management system (i.e. the MySQL server) is running (usually localhost if
// the web files are on the same server as the RDBMS)
// NB:
// The database and permissions for accessing it must be created using your RDBMS client. Wikindx
// will NOT do this for you.  If unsure how to do this, contact your server admin. After you have 
// set up an empty database with the correct permissions (GRANT ALL), the first running of Wikindx 
// will create the necessary database tables.
$WIKINDX_DB_HOST = "localhost";
// name of the database which these scripts interface with:
$WIKINDX_DB = "wikindx3";
// username and password required to connect to and open the database (it is strongly 
// recommended that you change these default values):
$WIKINDX_DB_USER = "wikindx";
$WIKINDX_DB_PASSWORD = "wikindx";
//This version only supports 'mysql' so do not change this.
$WIKINDX_DB_TYPE = "mysql";
// WIKINDX uses MySQL persistent connections by default.  Some hosting services are not configured for this: if you have problems 
// connecting to your MySQL server and/or receive error messages about 'too many connections', set $WIKINDX_DB_PERSISTENT to FALSE
$WIKINDX_DB_PERSISTENT = TRUE;
/*****
END DATABASE CONFIGURATION
*****/

/**********************************************************************************/

/*****
START AUTHORIZATION CONFIGURATION
*****/
// $WIKINDX_DENY_READONLY is TRUE, read only access is denied and only logged on users can access the WIKINDX.
// Although contrary to my philosophy of sharing knowledge, I've bowed to the inevitable pressure.
$WIKINDX_DENY_READONLY = FALSE;
// If $WIKINDX_READONLYACCESS is TRUE, an initial attempt to access WIKINDX will automatically grant that user read only access if there is no 
// write access cookie set and $WIKINDX_DENY_READONLY is FALSE.  Setting this to FALSE, will present the user with the logon prompt.
$WIKINDX_READONLYACCESS = TRUE;
/*****
END AUTHORIZATION CONFIGURATION
*****/

/**********************************************************************************/

/******
START SESSION CONFIGURATION
******/
// On some ISPs, disk quotas are set on session storage directories.  WIKINDX is a heavy user of sessions and the folder set for storing session data may fill up 
// quickly causing session write errors.  This variable sets an alternate path for storing sessions.  If this variable does not exist or has no value, the default session 
// path, as set in php.ini, will be used.  If it exists and has a value, the directory must exist and be writable by the web server user.
// There should be no trailing '\' or '/'.
// Example for a windows system:
// $WIKINDX_SESSION_PATH = "D:\sessions";

// If $WIKINDX_SESSION_PATH is set, this value will remove sessions in that directory older than xx days.  Set to 0 to never remove sessions.
// The value will be ignored if $WIKINDX_SESSION_PATH does not exist or is empty.
$WIKINDX_SESSION_PATH_CLEAR = 10;
/******
ENDSESSION CONFIGURATION
******/

/**********************************************************************************/

/******
START DIRECTORY PATH CONFIGURATION
******/
// Alternate locations for storing SUWP papers, attachments and exported files.  If these do not exist or are commented out, the default locations at the 
// top level of wikindx3/ will be used.  It is the adminstrator's responsibility to ensure that these directories are web-server user readable and writeable.
// There should be no trailing '\' or '/'.
//$WIKINDX_PAPERS_DIR = "D:\papers";
//$WIKINDX_ATTACHMENTS_DIR = "D:\attachments";
//$WIKINDX_FILES_DIR = "D:\files";
/******
END DIRECTORY PATH CONFIGURATION
******/

/**********************************************************************************/

/*****
START ERROR and DEBUGGING CONFIGURATION
*****/
// Set the following to TRUE to turn on error reporting
$WIKINDX_ERROR_REPORTING = FALSE;
/*****
END ERROR and DEBUGGING CONFIGURATION
*****/

/**********************************************************************************/

/*****
START RESOURCE TYPE CONFIGURATION
*****/
// Deactivate resource types.  Simply uncomment those resource types that you wish to be disabled.
// Deactivated resource types that are already in the database will not have their display affected.
// The importing and exporting of bibliographies will ignore deactivated resource types in this list.
$WIKINDX_DEACTIVATE_RESOURCE_TYPES = array(
// 'book',
// 'book_article',
// 'journal_article',
// 'newspaper_article',
// 'magazine_article',
// 'proceedings',
// 'conference_paper',
// 'proceedings_article',
// 'thesis',
// 'web_article',
// 'film',
// 'broadcast',
// 'music_album',
// 'music_track',
// 'music_score',
// 'artwork',
// 'software',
// 'audiovisual',
// 'database',
// 'government_report',
// 'report',
// 'hearing',
// 'statute',
// 'legal_ruling',
// 'case', 'bill',
// 'patent',
// 'personal',
// 'unpublished',
// 'classical',
// 'manuscript',
// 'map',
// 'chart',
// 'miscellaneous',
// 'miscellaneous_section',
// 'web_site',
);
/*****
END RESOURCE TYPE CONFIGURATION
*****/

/**********************************************************************************/

/*****
START  RSS CONFIGURATION (see rss.php)
*****/
// These are only required if you wish to run a RSS news feed for the latest additions to your WIKINDX.  
// No. of items to send to the feed.
$WIKINDX_RSS_LIMIT = 10;
// WIKINDX main address as a base for adding the resource view querystring.  This should be the full external hostname.
$WIKINDX_RSS_HOST = "http://localhost/wikindx3/index.php";
// Bibliographic style (UPPERCASE one of the directory names in wikindx/styles/bibliography/)
$WIKINDX_RSS_BIBSTYLE = "APA";
// Set this to FALSE to display only recently added resources or to TRUE to display recently added AND edited resources
$WIKINDX_RSS_DISPLAY = TRUE;
// RSS Title
$WIKINDX_RSS_TITLE = "WIKINDX";
// RSS Description
$WIKINDX_RSS_DESCRIPTION = "My Wikindx";
// RSS Language
$WIKINDX_RSS_LANGUAGE = "en";
/*****
END RSS CONFIGURATION
*****/
?>

==> wikindx3_5.tar.gz: wikindx3/config.php <==
<?php
/**********************************************************************************
WIKINDX: Bibliographic Management system.
Copyright (C)

This program is free software; you can redistribute it and/or modify it under the terms 
of the GNU General Public License as published by the Free Software Foundation; either 
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; 
if not, write to the 
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

The WIKINDX Team 2007
sirfragalot@users.sourceforge.net
**********************************************************************************/
/*****
*
* WIKINDX v3.x CONFIGURATION FILE
*
* NB. BEFORE YOU MAKE CHANGES TO THIS FILE, BACK IT UP!
* NB. BEFORE YOU MAKE CHANGES TO THIS FILE, BACK IT UP!
* NB. BEFORE YOU MAKE CHANGES TO THIS FILE, BACK IT UP!
*
* If you make changes, backup the edited file as future upgrades of WIKINDX will write over this file - no questions asked!
*****/

/**********************************************************************************/

/*****
START DATABASE CONFIGURATION
*****/
// host on which the relational db management system (i.e. the MySQL server) is running (usually localhost if
// the web files are on the same server as the RDBMS)
// NB:
// The database and permissions for accessing it must be created using your RDBMS client. Wikindx
// will NOT do this for you.  If unsure how to do this, contact your server admin. After you have 
// set up an empty database with the correct permissions (GRANT ALL), the first running of Wikindx 
// will create the necessary database tables.
$WIKINDX_DB_HOST = "localhost";
// name of the database which these scripts interface with:
$WIKINDX_DB = "wikindx3";
// username and password required to connect to and open the database (it is strongly 
// recommended that you change these default values):
$WIKINDX_DB_USER = "wikindx";
$WIKINDX_DB_PASSWORD = "wikindx";
//This version only supports 'mysql' so do not change this.
$WIKINDX_DB_TYPE = "mysql";
// WIKINDX uses MySQL persistent connections by default.  Some hosting services are not configured for this: if you have problems 
// connecting to your MySQL server and/or receive error messages about 'too many connections', set $WIKINDX_DB_PERSISTENT to FALSE
$WIKINDX_DB_PERSISTENT = TRUE;
/*****
END DATABASE CONFIGURATION
*****/

/**********************************************************************************/

/*****
START AUTHORIZATION CONFIGURATION
*****/
// If $WIKINDX_DENY_READONLY is TRUE, read only access is denied and only logged on users can access the WIKINDX.
// (Although contrary to my philosophy of sharing knowledge, I've bowed to the inevitable pressure.)
$WIKINDX_DENY_READONLY = FALSE;
// If $WIKINDX_READONLYACCESS is TRUE, an initial attempt to access WIKINDX will automatically grant that user read only access if there is no 
// write access cookie set and $WIKINDX_DENY_READONLY is FALSE.  Setting this to FALSE, will present the user with the logon prompt.
$WIKINDX_READONLYACCESS = TRUE;
/*****
END AUTHORIZATION CONFIGURATION
*****/

/**********************************************************************************/

/******
START SESSION CONFIGURATION
******/
// On some ISPs, disk quotas are set on session storage directories.  WIKINDX is a heavy user of sessions and the folder set for storing session data may fill up 
// quickly causing session write errors.  This variable sets an alternate path for storing sessions.  If this variable does not exist or has no value, the default session 
// path, as set in php.ini, will be used.  If it exists and has a value, the directory must exist and be writable by the web server user.
// There should be no trailing '\' or '/'.
// Example for a windows system:
// $WIKINDX_SESSION_PATH = "D:\sessions";

// If $WIKINDX_SESSION_PATH is set, this value will remove sessions in that directory older than xx days.  Set to 0 to never remove sessions.
// The value will be ignored if $WIKINDX_SESSION_PATH does not exist or is empty.
$WIKINDX_SESSION_PATH_CLEAR = 10;
/******
ENDSESSION CONFIGURATION
******/

/**********************************************************************************/

/******
START DIRECTORY PATH CONFIGURATION
******/
// Alternate locations for storing SUWP papers, attachments and exported files.  If these do not exist or are commented out, the default locations at the 
// top level of wikindx3/ will be used.  It is the adminstrator's responsibility to ensure that these directories are web-server user readable and writeable.
// There should be no trailing '\' or '/'.
//$WIKINDX_PAPERS_DIR = "D:\papers";
//$WIKINDX_ATTACHMENTS_DIR = "D:\attachments";
//$WIKINDX_FILES_DIR = "D:\files";
/******
END DIRECTORY PATH CONFIGURATION
******/

/**********************************************************************************/

/*****
START ERROR and DEBUGGING CONFIGURATION
*****/
// Set the following to TRUE to turn on error reporting
$WIKINDX_ERROR_REPORTING = FALSE;
/*****
END ERROR and DEBUGGING CONFIGURATION
*****/

/**********************************************************************************/

/*****
START RESOURCE TYPE CONFIGURATION
*****/
// Deactivate resource types.  Simply uncomment those resource types that you wish to be disabled.
// Deactivated resource types that are already in the database will not have their display affected.
// The importing and exporting of bibliographies will ignore deactivated resource types in this list.
$WIKINDX_DEACTIVATE_RESOURCE_TYPES = array(
// 'book',
// 'book_article',
// 'journal_article',
// 'newspaper_article',
// 'magazine_article',
// 'proceedings',
// 'conference_paper',
// 'proceedings_article',
// 'thesis',
// 'web_article',
// 'film',
// 'broadcast',
// 'music_album',
// 'music_track',
// 'music_score',
// 'artwork',
// 'software',
// 'audiovisual',
// 'database',
// 'government_report',
// 'report',
// 'hearing',
// 'statute',
// 'legal_ruling',
// 'case',
// 'bill',
// 'patent',
// 'personal',
// 'unpublished',
// 'classical',
// 'manuscript',
// 'map',
// 'chart',
// 'miscellaneous',
// 'miscellaneous_section',
// 'web_site',
// 'book_chapter',
);
/*****
END RESOURCE TYPE CONFIGURATION
*****/

/**********************************************************************************/

/*****
START  RSS CONFIGURATION (see rss.php)
*****/
// These are only required if you wish to run a RSS news feed for the latest additions to your WIKINDX.  
// No. of items to send to the feed.
$WIKINDX_RSS_LIMIT = 10;
// WIKINDX main address as a base for adding the resource view querystring.  This should be the full external hostname and path.
$WIKINDX_RSS_HOST = "http://localhost/wikindx3/index.php";
// Bibliographic style (UPPERCASE one of the directory names in wikindx/styles/bibliography/)
$WIKINDX_RSS_BIBSTYLE = "APA";
// Set this to FALSE to display only recently added resources or to TRUE to display recently added AND edited resources.
$WIKINDX_RSS_DISPLAY = TRUE;
// RSS Title
$WIKINDX_RSS_TITLE = "WIKINDX";
// RSS Description
$WIKINDX_RSS_DESCRIPTION = "My Wikindx";
// RSS Language
$WIKINDX_RSS_LANGUAGE = "en";
/*****
END RSS CONFIGURATION
*****/
?>
